@@ -8,7 +8,8 @@ c      INCLUDE 'series.txt'
 c      INCLUDE 'model.txt'
 c      INCLUDE 'repar3.txt'
 C*****kfasav.txt
-      REAL PRE(5000),PRV(5000),FSER(5000),FVAR(5000),SSER(5000)
+      DOUBLE PRECISION PRE(5000),PRV(5000),FSER(5000),FVAR(5000)
+     1,SSER(5000)
      1,SVAR(5000)
       DOUBLE PRECISION FSES(5000,20),FSCV(5000,20,20),SSES(5000,20)
      1,SSCV(5000,20,20),PSES(5000,20),PSCV(5000,20,20),TRAN(5000,20,20)
